from setuptools import setup, find_packages

setup(name = "simpleSound", version = "1.0.0a", author = "nekumelon", author_email = "nekumelon@gmail.com", packages = find_packages(), description = "A very very very simple sound playing library for windows.", url = "https://github.com/nekumelon/simpleSound", license = "MIT", install_requires = ["ctypes", "os"]);